@@ -1,4 +1,4 @@
-# $Id: Order.pm 665 2005-08-07 00:10:59Z claco $
+# $Id: Order.pm 1314 2006-07-10 00:29:55Z claco $
 package AxKit::XSP::Handel::Order;
 use strict;
 use warnings;
@@ -11,9 +11,22 @@ use base 'Apache::AxKit::Language::XSP';
 
 $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
 
-{
+#{
     my @context = 'root';
 
+    sub push_context {
+        my @nodes = @_;
+        push @context, @nodes;
+    };
+
+    sub pop_context {
+        my $count = shift;
+
+        foreach (1..$count) {
+            pop @context;
+        };
+    };
+
     sub start_document {
         return "use Handel::Order;\n";
     };
@@ -74,7 +87,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         ## order:uuid
         if ($tag =~ /^(g|u)uid$/) {
             $e->start_expr($tag);
-            $e->append_to_script("Handel::Order->uuid");
+            $e->append_to_script("Handel::Order->storage->new_uuid");
             $e->end_expr($tag);
 
         ## order:new
@@ -85,10 +98,10 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
 
             push @context, $tag;
 
-            my $noprocess = $attr{'noprocess'} || 0;
-            delete $attr{'noprocess'};
+            my $process = $attr{'process'} || 0;
+            delete $attr{'process'};
 
-            my $code = "my \$_xsp_handel_order_new_noprocess = $noprocess;my \$_xsp_handel_order_order;\nmy \$_xsp_handel_order_called_new;\n";
+            my $code = "my \$_xsp_handel_order_new_process = $process;my \$_xsp_handel_order_order;\nmy \$_xsp_handel_order_called_new;\n";
             $code .= scalar keys %attr ?
                 'my %_xsp_handel_order_new_filter = ("' . join('", "', %attr) . '");' :
                 'my %_xsp_handel_order_new_filter;' ;
@@ -383,7 +396,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
             if ($context[$#context-1] eq 'new') {
                 return '
                     if (!$_xsp_handel_order_called_new && scalar keys %_xsp_handel_order_new_filter) {
-                        $_xsp_handel_order_order = Handel::Order->new(\%_xsp_handel_order_new_filter, $_xsp_handel_order_new_noprocess);
+                        $_xsp_handel_order_order = Handel::Order->new(\%_xsp_handel_order_new_filter, $_xsp_handel_order_new_process);
                         $_xsp_handel_order_called_new = 1;
                     };
                     if ($_xsp_handel_order_order) {
@@ -456,7 +469,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
             if ($context[$#context-1] eq 'new') {
                 return '
                     if (!$_xsp_handel_order_called_new && scalar keys %_xsp_handel_order_new_filter) {
-                        $_xsp_handel_order_order = Handel::Order->new(\%_xsp_handel_order_new_filter, $_xsp_handel_order_new_noprocess);
+                        $_xsp_handel_order_order = Handel::Order->new(\%_xsp_handel_order_new_filter, $_xsp_handel_order_new_process);
                         $_xsp_handel_order_called_new = 1;
                     };
                     if (!$_xsp_handel_order_order) {
@@ -590,11 +603,13 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                 pop @context;
                 return '
                     $_xsp_handel_order_order->update;
+                    $_xsp_handel_order_order->autoupdate(1);
                 ';
             } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
                 pop @context;
                 return '
                     $_xsp_handel_order_item->update;
+                    $_xsp_handel_order_item->autoupdate(1);
                 ';
             };
 
@@ -749,7 +764,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
 
         return '';
     };
-};
+#};
 
 1;
 __END__
@@ -1430,13 +1445,13 @@ The child tags take precedence over the attributes of the same name.
 C<new> B<must be a top level tag> within it's declared namespace.
 It will throw an C<Handel::Exception::Taglib> exception otherwise.
 
-When true, the C<process> attribute forces new to automaticly create
-a checkout process and initialize the currecnt order.
-See L<Handel::Order/"new"> for more informaiton on the process flag.
+When true, the C<process> attribute forces new to automatically create
+a checkout process and initialize the current order.
+See L<Handel::Order/"new"> for more information on the process flag.
 
 =head2 <order:number>
 
-Context aware tag that gets or sets the order numnber.
+Context aware tag that gets or sets the order number.
 
 =head2 <order:order>
 
@@ -1614,7 +1629,7 @@ as is.
 =head3 Precedence
 
 If you are using both the currency conversion and the currency formatting
-options, the conversion will be performaed first, then the result will
+options, the conversion will be performed first, then the result will
 be formatted.
 
 =head2 <order:quantity>
@@ -1658,7 +1673,7 @@ for the order item:
 
 =head2 <order:updated>
 
-COntext aware tag that gets or sets the order last updated date.
+Context aware tag that gets or sets the order last updated date.
 
 =head2 <order:update>
 
@@ -1697,7 +1712,7 @@ forms are valid for your syntactic sanity:
 =head2 <order:no-results>
 
 The anti-results or 'not found' tag. This tag is executed when
-C<order>, C<orders>, C<item>, or C<items> fails to fild a match for it's filters.
+C<order>, C<orders>, C<item>, or C<items> fails to find a match for it's filters.
 As with C<E<lt>order:resultsE<gt>>, both the
 singular and plural forms are available for your enjoyment:
 
