@@ -1,4 +1,4 @@
-# $Id: Checkout.pm 1310 2006-07-09 04:01:49Z claco $
+# $Id: Checkout.pm 1339 2006-07-15 21:49:41Z claco $
 package Handel::Checkout;
 use strict;
 use warnings;
@@ -7,14 +7,15 @@ BEGIN {
     use Handel;
     use Handel::Cart;
     use Handel::Checkout::Stash;
-    use Handel::Constants qw(:checkout :returnas);
-    use Handel::Constraints qw(constraint_checkout_phase constraint_uuid);
-    use Handel::Exception qw(:try);
+    use Handel::Constants qw/:all/;
+    use Handel::Constraints qw/constraint_checkout_phase constraint_uuid/;
+    use Handel::Exception qw/:try/;
     use Handel::Checkout::Message;
-    use Handel::L10N qw(translate);
+    use Handel::L10N qw/translate/;
     use Handel::Order;
     use Module::Pluggable 2.95 instantiate => 'new', sub_name => '_plugins';
     use Class::Inspector;
+    use Scalar::Util qw/blessed/;
 
     use base qw/Class::Accessor::Grouped/;
     __PACKAGE__->mk_group_accessors('component_class', qw/order_class stash_class/);
@@ -37,7 +38,7 @@ sub new {
     $self->_set_search_path($opts);
 
     foreach ($self->_plugins($self)) {
-        if (UNIVERSAL::isa($_, 'Handel::Checkout::Plugin')) {
+        if (blessed($_) && $_->isa('Handel::Checkout::Plugin')) {
             push @{$self->{'plugins'}}, $_;
             $_->register($self);
         };
@@ -93,7 +94,7 @@ sub add_message {
     my ($self, $message) = @_;
     my ($package, $filename, $line) = caller;
 
-    if (ref $message && UNIVERSAL::isa($message, 'Handel::Checkout::Message')) {
+    if (blessed($message) && $message->isa('Handel::Checkout::Message')) {
         $message->package($package) unless $message->package;
         $message->filename($filename) unless $message->filename;
         $message->line($line) unless $message->line;
@@ -148,7 +149,7 @@ sub cart {
     my ($self, $cart) = @_;
 
     if ($cart) {
-        if (ref $cart eq 'HASH' || UNIVERSAL::isa($cart, 'Handel::Cart') || constraint_uuid($cart)) {
+        if (ref $cart eq 'HASH' || (blessed($cart) && $cart->isa('Handel::Cart')) || constraint_uuid($cart)) {
             $self->order($self->order_class->new({cart => $cart}));
         } else {
             throw Handel::Exception::Argument( -details =>
@@ -168,8 +169,8 @@ sub order {
 
     if ($order) {
         if (ref $order eq 'HASH') {
-            $self->{'order'} = $self->order_class->load($order, RETURNAS_ITERATOR)->first;
-        } elsif (UNIVERSAL::isa($order, 'Handel::Order')) {
+            $self->{'order'} = $self->order_class->load($order)->first;
+        } elsif ( blessed($order) && $order->isa('Handel::Order')) {
             $self->{'order'} = $order;
         } elsif (constraint_uuid($order)) {
             $self->{'order'} = $self->order_class->load({id => $order})->first;
@@ -378,12 +379,14 @@ Handel::Checkout - Checkout Pipeline Processor
 =head1 SYNOPSIS
 
     use Handel::Checkout;
-
+    use strict;
+    use warnings;
+    
     my $checkout = Handel::Checkout->new({
         cart    => '122345678-9098-7654-3212-345678909876',
         phases  => [CHECKOUT_PHASE_INITIALIZE, CHECKOUT_PHASE_VALIDATE]
     });
-
+    
     if ($checkout->process == CHECKOUT_STATUS_OK) {
         print 'Your order number is ', $checkout->order->number;
     } else {
@@ -400,31 +403,41 @@ allowing the checkout process to be customized for many different needs.
 
 =head1 CONSTRUCTOR
 
-=head2 new([\%options])
+=head2 new
 
-Creates a new checkout pipeline process and loads all available plugins.
-C<new> accepts the following options in an optional HASH reference:
+=over
+
+=item Arguments: \%options
+
+=back
+
+Creates a new checkout pipeline process and loads all available plugins in the
+default plugin namespace (Handel::Checkout::Plugin). C<new> accepts the
+following options in an optional HASH reference:
 
 =over
 
 =item cart
 
-A HASH reference, Handel::Cart object, or a cart id. This will be loaded
-into a new Handel::Order object and associated with the new checkout
-process.
+A HASH reference, a class object, or a cart id. This will be loaded
+into a new order object and associated with the new checkout
+process. By default, a Handel::Order object will be create unless you have
+set C<order_class> to another class.
 
 See C<cart> below for further details about the various values allowed
 to be passed.
 
 B<Note>: When creating a new order via Handel::Order, C<new> will automatically
-create a checkout process and process the C<CHECKOUT_PHASE_INITIALIZE>.
+create a checkout process and process the C<CHECKOUT_PHASE_INITIALIZE> phase.
 However, when a new order is created using C<cart> in Handel::Checkout, the
 automatic processing of C<CHECKOUT_PHASE_INITIALIZE> is disabled.
 
 =item order
 
-A HASH reference, Handel::Order object, or an order id. This will be loaded
-and associated with the new checkout process.
+A HASH reference, an order object, or an order id. This will be loaded
+and associated with the new checkout process. By default, a Handel::Order
+object will be create when you pass in an order id unless you have set
+C<order_class> to another class.
 
 See C<order> below for further details about the various values allowed
 to be passed.
@@ -433,17 +446,17 @@ to be passed.
 
 An array reference or a comma (or space) separated list containing the various
 namespaces of plugins to be loaded. This will override any settings in
-C<ENV> or F<httpd.conf> for the current checkout instance only.
+C<ENV> or F<httpd.conf> for the current checkout object only.
 
     my $checkout = Handel::Checkout->new({
         pluginpaths => [MyNamespace::Plugins, Other::Plugin]
     });
-
+    
     my $checkout = Handel::Checkout->new({
         pluginpaths => 'MyNamespace::Plugins, Other::Plugin'
     });
 
-See L<"HandelPluginPaths"> for more information about settings/resetting
+See L</HandelPluginPaths> for more information about settings/resetting
 plugin search paths.
 
 =item addpluginpaths
@@ -455,12 +468,12 @@ If C<HandelAddPluginPaths> is also specified, the two will be combined.
     my $checkout = Handel::Checkout->new({
         addpluginpaths => [MyNamespace::Plugins, Other::Plugin]
     });
-
+    
     my $checkout = Handel::Checkout->new({
         addpluginpaths => 'MyNamespace::Plugins, Other::Plugin'
     });
 
-See L<"HandelAddPluginPaths"> for more information about settings/resetting
+See L</HandelAddPluginPaths> for more information about settings/resetting
 plugin search paths.
 
 =item loadplugins
@@ -468,7 +481,7 @@ plugin search paths.
 An array reference or a comma (or space) separated list containing the
 names of the specific plugins to load in the current plugin paths.
 
-See L<"HandelLoadPlugins"> for more information about loading specific
+See L</HandelLoadPlugins> for more information about loading specific
 plugins.
 
 =item ignoreplugins
@@ -477,7 +490,7 @@ An array reference or a comma (or space) separated list containing the
 names of the specific plugins to be ignored (not loaded)
 in the current plugin paths.
 
-See L<"HandelIgnorePlugins"> for more information about ignore specific
+See L</HandelIgnorePlugins> for more information about ignore specific
 plugins.
 
 =item phases
@@ -489,32 +502,38 @@ various phases to be executed.
         phases => [CHECKOUT_PHASE_VALIDATION,
                    CHECKOUT_PHASE_AUTHORIZATION]
     });
-
+    
     my $checkout = Handel::Checkout->new({
         phases => 'CHECKOUT_PHASE_VALIDATION, CHECKOUT_PHASE_AUTHORIZATION'
     });
 
 =item stash
 
-A Handel::Checkout::Stash instance of subclass instance. If nothing is specified,
-$self->stash_class will be used instead.
+A Handel::Checkout::Stash object or subclass. If nothing is
+specified, C<stash_class> will be used instead.
 
 =back
 
 =head1 METHODS
 
-=head2 add_handler($phase, \&coderef, $preference)
+=head2 add_handler
 
-Registers a code reference with the checkout phase specified and assigned a run
+=over
+
+=item Arguments: $phase, \&coderef, $preference
+
+=back
+
+Registers a code reference with the checkout phase specified and assigns a run
 order preference. This is usually called within C<register> on the current
-checkout context:
+checkout context within a plugin:
 
     sub register {
         my ($self, $ctx) = @_;
 
         $ctx->add_handler(CHECKOUT_PHASE_DELIVER, \&myhandler, 200);
     };
-
+    
     sub myhandler {
         ...
     };
@@ -525,11 +544,17 @@ list after all other handlers in that phase.
 If there is already a handler in the specified phase with the same preference, a
 Handel::Exception::Checkout exception will be thrown.
 
-While not enforced, please keep your handler preference orders between 251 - 749.
-Preference orders 1-250 and 750-1000 will be reserved for core modules that need
-to run before or after all other plugin handlers.
+While not enforced, please keep your handler preference orders between
+251 - 749. Preference orders 1-250 and 750-1000 will be reserved for core
+modules that need to run before or after all other plugin handlers.
 
-=head2 add_message($message)
+=head2 add_message
+
+=over
+
+=item Arguments: $message
+
+=back
 
 Adds a new text message or Handel::Checkout::Message based object
 to the message stack so plugins can log their issues for later inspection.
@@ -538,7 +563,7 @@ to the message stack so plugins can log their issues for later inspection.
         my ($self, $ctx) = @_;
         ...
         $ctx->add_message('Skipping phase for countries other than US...');
-
+    
         return CHECKOUT_HANDLER_DECLINE;
     };
 
@@ -547,34 +572,46 @@ If your adding a simple text message, a new Handel::Checkout::Message object
 will automatically be created and C<package>, C<filename>, and C<line>
 properties will be set.
 
-=head2 add_phase($name, $value [, $import]);
+=head2 add_phase
+
+=over
+
+=item Arguments: $name, $value [, $import]
+
+=back
 
 Adds a new constant/sub named $name to Handel::Constant and adds the $value to
-CHECKOUT_ALL_PHASES. The new phase will be accepted by &constraint_checkout_phase
-and can be used by checkout plugins registering their handlers via
-add_handler($phase, &handler). If $import is true, add_phase will register the
-constant in the local namespace just as if it you had specified it in your use
-statement.
+CHECKOUT_ALL_PHASES. The new phase will be accepted by
+C<constraint_checkout_phase> and can be used by checkout plugins registering
+their handlers via add_handler($phase, &handler). If $import is true,
+C<add_phase> will register the constant in the local namespace just as if it
+you had specified it in your use statement.
 
     use Handel::Checkout;
-
+    
     Handel::Checkout->add_phase('CHECKOUT_PHASE_CUSTOMPHASE', 42, 1);
-
+    
     print constraint_checkout_phase(&CHECKOUT_PHASE_CUSTOMPHASE);
-
-    $plugincontext->add_handler(Handel::Constants::CHECKOUT_PHASE_CUSTOMPHASE, &handlersub);
+    
+    $plugincontext->add_handler(
+        Handel::Constants::CHECKOUT_PHASE_CUSTOMPHASE, &handlersub
+    );
 
 =head2 clear_messages
 
-Clears all messages from the current checkout instance.
+Clears all messages from the current checkout object.
 
 =head2 cart
 
-Creates a new Handel::Order object from the specified cart and associates
+Creates a new order object from the specified cart and associates
 that order with the current checkout process. This is typically only needed
 the first time you want to run checkout for a specific cart. From then on,
 you only need to load the already created order using C<order> below.
 
+By default, a Handel::Order object will be create unless you have
+set C<order_class> to another class. When the order class loads a cart by id, it
+will create a cart using the C<cart_class> set in the C<order_class>.
+
 C<cart> can accept one of three possible parameter values:
 
 =over
@@ -582,67 +619,83 @@ C<cart> can accept one of three possible parameter values:
 =item cart(\%filter)
 
 When you pass a HASH reference, C<cart> will attempt to load all available
-carts using Handel::Cart::load(\%filter). If multiple carts are found, only
-the first one will be used.
+carts. If multiple carts are found, only the first one will be used.
 
     $checkout->cart({
         shopper => '12345678-9098-7654-3212-345678909876',
         type => CART_TYPE_TEMP
     });
 
-=item cart(Handel::Cart)
+=item cart($cart)
 
 You can also pass in an already existing Handel::Cart object or subclass. It
-will then be loaded into a new order object ans associated with the current
+will then be loaded into a new order object and associated with the current
 checkout process.
 
     my $cart = Handel::Cart->load({
         id => '12345678-9098-7654-3212-345678909876'
     });
-
+    
     $checkout->cart($cart);
 
-=item cart($cartid)
+=item cart('11111111-1111-1111-1111-111111111111')
 
-Finally, you can pass a valid cart/uuid into C<cart>. The matching cart
-will be loaded into a new Handel::Order object and associated with the
-current checkout process.
+Finally, you can pass a valid cart/uuid into C<cart>. The matching cart will be
+loaded into a new order object and associated with the current checkout
+process.
 
     $checkout->cart('12345678-9098-7654-3212-345678909876');
 
 =back
 
-=head2 order_class($orderclass)
+=head2 order_class
 
-Gets/Sets the name of the class to use when loading existing order into the
-checkout process. By default, it loads order using Handel::Order. While you can
-set this directly in your application, it's best to set it in a custom subclass
-of Handel::Checkout.
+=over
+
+=item Arguments: $order_class
+
+=back
+
+Gets/sets the name of the class to use when loading an existing order into the
+checkout process or when creating a new order from an existing cart. By default,
+it loads order using Handel::Order. While you can set this directly in your
+application, it's best to set it in a custom subclass of Handel::Checkout.
 
     package CustomCheckout;
-    use base 'Handel::Checkout';
+    use strict;
+    use warnings;
+    use base qw/Handel::Checkout/;
     __PACKAGE__->order_class('CustomOrder');
-
+    
     ...
     use CustomCheckout;
-    my $checkout = CustomCheckout->new({order => '11111111-2222-3333-4444-555555555555'});
-
+    my $checkout = CustomCheckout->new({
+        order => '11111111-2222-3333-4444-555555555555'
+    });
+    
     print ref $checkout->order; # CustomOrder
 
-=head2 stash_class($stashclass)
+=head2 stash_class
 
-Gets/Sets the name of the stash class to create during C<new>. By default, it
-returns Handel::Checkout::Stash. While you can
-set this directly in your application, it's best to set it in a custom subclass
-of Handel::Checkout.
+=over
+
+=item Arguments: $stash_class
+
+=back
+
+Gets/sets the name of the stash class to create during C<new>. By default, it
+returns Handel::Checkout::Stash. While you can set this directly in your
+application, it's best to set it in a custom subclass of Handel::Checkout.
 
     package CustomCheckout;
-    use base 'Handel::Checkout';
+    use strict;
+    use warnings;
+    use base qw/Handel::Checkout/;
     __PACKAGE__->stash_class('MyCustomStash');
 
 =head2 messages
 
-Returns a reference to an array in list context of Handel::Checkout::Message
+Returns a reference to an array in scalar context of Handel::Checkout::Message
 objects containing additional information about plugin and other checkout
 decisions and activities. Returns a list in list context.
 
@@ -652,11 +705,11 @@ decisions and activities. Returns a list in list context.
 
 =head2 plugins
 
-Returns a list plugins loaded for checkout instance in list context:
+Returns a list plugins loaded for current checkout object in list context:
 
     my $checkout = Handel::Checkout->new;
     my @plugins = $checkout->plugins;
-
+    
     foreach (@plugins) {
         $_->cleanup_or_something;
     };
@@ -665,7 +718,9 @@ Returns an array reference in scalar context.
 
 =head2 order
 
-Gets/Sets an existing Handel::Order object with the existing checkout process.
+Gets/sets an existing order object with the existing checkout process. By
+default, a Handel::Order object will be create unless you have set
+C<order_class> to another class.
 
 C<order> can accept one of three possible parameter values:
 
@@ -674,15 +729,14 @@ C<order> can accept one of three possible parameter values:
 =item order(\%filter)
 
 When you pass a HASH reference, C<order> will attempt to load all available
-order using Handel::Order::load(\%filter). If multiple order are found, only
-the first one will be used.
+orders. If multiple order are found, only the first one will be used.
 
     $checkout->order({
         shopper => '12345678-9098-7654-3212-345678909876',
         id => '11111111-2222-3333-4444-5555666677778888'
     });
 
-=item order(Handel::Order)
+=item order($order)
 
 You can also pass in an already existing Handel::Order object or subclass. It
 will then be associated with the current checkout process.
@@ -690,10 +744,10 @@ will then be associated with the current checkout process.
     my $order = Handel::Order->load({
         id => '12345678-9098-7654-3212-345678909876'
     });
-
+    
     $checkout->order($order);
 
-=item order($orderid)
+=item order('11111111-1111-1111-1111-111111111111')
 
 Finally, you can pass a valid order/uuid into C<order>. The matching order
 will be loaded and associated with the current checkout process.
@@ -702,45 +756,60 @@ will be loaded and associated with the current checkout process.
 
 =back
 
-=head2 phases(\@phases)
+=head2 phases
 
-Get/Set the phases active for the current checkout process. This can be
+=over
+
+=item Arguments: \@phases
+
+=back
+
+Gets/sets the phases active for the current checkout process. This can be
 an array reference or a comma (or space) separated string:
 
     $checkout->phases([
         CHECKOUT_PHASE_INITIALIZE,
         CHECKOUT_PHASE_VALIDATION
     ]);
-
+    
     $checkout->phases('CHECKOUT_PHASE_INITIALIZE, CHECKOUT_PHASE_VALIDATION']);
 
-No attempt is made to sanitize the array for duplicates or the order of the phases.
-This means you can do evil things like run a phase twice, or run the phases
-out of order. Returns a list in list context and an array reference in scalar context.
+No attempt is made to sanitize the array for duplicates or the order of the
+phases. This means you can do evil things like run a phase twice, or run the
+phases out of order. Returns a list in list context and an array reference in
+scalar context.
 
-=head2 process([\@phases])
+=head2 process
+
+=over
+
+=item Arguments: \@phases
+
+=back
 
 Executes the current checkout process pipeline and returns CHECKOUT_STATUS_*.
-Any plugin handler that doesn't return CHECKOUT_HANDLER_OK or CHECKOUT_HANDLER_DECLINE
-is considered to be an error that the checkout process is aborted.
+Any plugin handler that doesn't return CHECKOUT_HANDLER_OK or
+CHECKOUT_HANDLER_DECLINE is considered to be an error that the checkout process
+is aborted.
 
 Just like C<phases>, you can pass an array reference or a comma (or space)
 separated string of phases into process.
 
-The method $self->stash->clear is called before the call to
-$plugin->setup so plugins can set stash data, and the stash remains until the
-next call to process so $plugin->teardown can read any remaining stash data
+The C<clear> method is called on the stash before the call to C<setup> on each
+plugin so plugins can set stash data, and the stash remains until the next call
+to process so $plugin->teardown can read any remaining stash data
 before C<process> ends.
 
-The call to C<process> will return on of the following constants:
+The call to C<process> will return one of the following constants:
 
 =over
 
-=item CHECKOUT_STATUS_OK
+=item C<CHECKOUT_STATUS_OK>
 
-All plugin handlers were called and returned CHECKOUT_HANDLER_OK or CHECKOUT_HANDLER_DECLINE
+All plugin handlers were called and returned CHECKOUT_HANDLER_OK or
+CHECKOUT_HANDLER_DECLINE
 
-=item CHECKOUT_STATUS_ERROR
+=item C<CHECKOUT_STATUS_ERROR>
 
 At least one plugin failed to return or an error occurred while processing
 the registered plugin handlers.
@@ -749,8 +818,9 @@ the registered plugin handlers.
 
 =head2 stash
 
-Returns a Handel::Checkout::Stash object that can store information shared by
-all plugins in the current context.
+Returns a stash object that can store information shared by all plugins in the
+current context. By default, a Handel::Checkout::Stash object will be create
+unless you have set C<stash_class> to another class.
 
     # plugin handler
     my ($self, $ctx) = @_;
@@ -774,8 +844,8 @@ You can also pass a comma or space separate list of namespaces.
 
     PerlSetVar HandelPluginPaths 'MyApp::Plugins, OtherApp::Plugins'
 
-Any plugin found in the search path that isn't a subclass of Handel::Checkout::Plugin
-will be ignored.
+Any plugin found in the search path that isn't a subclass of
+Handel::Checkout::Plugin will be ignored.
 
 =head2 HandelAddPluginPaths
 
@@ -788,13 +858,14 @@ In the example above, when a checkout process is loaded, it will load
 all plugins in the Handel::Checkout::Plugin::*, MyApp::Plugins::*, and
 OtherApp::Plugins namespaces.
 
-Any plugin found in the search path that isn't a subclass of Handel::Checkout::Plugin
-will be ignored.
+Any plugin found in the search path that isn't a subclass of
+Handel::Checkout::Plugin will be ignored.
 
 =head2 HandelIgnorePlugins
 
-This is a comma/space separated list [or an anonymous array, or a regex outside of httpd.conf] of plugins to ignore when loading
-all available plugins in the given namespaces.
+This is a comma/space separated list [or an anonymous array, or a regex outside
+of httpd.conf] of plugins to ignore when loading all available plugins in the
+given namespaces.
 
     PerlSetVar HandelIgnorePlugins 'Handel::Checkout::Plugin::Initialize'
 
@@ -809,16 +880,18 @@ If the Handel::Checkout::Plugin namespace has the following modules:
     Handel::Checkout::Plugin::FaxDelivery
     Handel::Checkout::Plugin::EmailDelivery
 
-all of the modules above will be loaded <b>except</b> Handel::Checkout::Plugin::Initialize.
-All plugins in any other configured namespaces will be loaded.
+all of the modules above will be loaded <b>except</b>
+Handel::Checkout::Plugin::Initialize. All plugins in any other configured
+namespaces will be loaded.
 
-If both HandelLoadPlugins and HandelIgnorePlugins are specified, only the plugins in
-HandelLoadPlugins will be loaded, unless they are also in HandelIgnorePlugins in which case
-they will be ignored.
+If both HandelLoadPlugins and HandelIgnorePlugins are specified, only the
+plugins in HandelLoadPlugins will be loaded, unless they are also in
+HandelIgnorePlugins in which case they will be ignored.
 
 =head2 HandelLoadPlugins
 
-This is a comma or space separated list [or an anonymous array, or a regex outside of httpd.conf] of plugins to be loaded from the available namespaces.
+This is a comma or space separated list [or an anonymous array, or a regex
+outside of httpd.conf] of plugins to be loaded from the available namespaces.
 
     PerlSetVar HandelLoadPlugins 'Handel::Checkout::Plugin::ValidateAddress'
 
@@ -835,17 +908,18 @@ If the following plugins are available in all configured namespaces:
     MyApp::Plugin::VerifiedByVisa
     MyApp::Plugin::WarehouseUpdate
 
-only Handel::Checkout::Plugin::ValidateAddress will be loaded. All other plugins in all
-configured namespaces will be ignored.
+only Handel::Checkout::Plugin::ValidateAddress will be loaded. All other
+plugins in all configured namespaces will be ignored.
 
-If both HandelLoadPlugins and HandelIgnorePlugins are specified, only the plugins in
-HandelLoadPlugins will be loaded, unless they are also in HandelIgnorePlugins in which case
-they will be ignored.
+If both HandelLoadPlugins and HandelIgnorePlugins are specified, only the
+plugins in HandelLoadPlugins will be loaded, unless they are also in
+HandelIgnorePlugins in which case they will be ignored.
 
 =head1 CAVEATS
 
-[I think] Due to the localization of AutoCommit to coerce disabling of autoupdates during process,
-Always access orders and order items from their checkout parent once they've been assigned to
+[I think] Due to the localization of AutoCommit to coerce disabling of
+autoupdates during process, Always access orders and order items from their
+checkout parent once they've been assigned to
 the checkout process, and not any available reference:
 
     my $order = Handel::Order->new({billtofirstname => 'Chris'});
