@@ -1,11 +1,13 @@
-# $Id: Constants.pm 696 2005-08-10 01:29:25Z claco $
+# $Id: Constants.pm 1335 2006-07-15 02:43:12Z claco $
 package Handel::Constants;
 use strict;
 use warnings;
-use vars qw(@EXPORT_OK %EXPORT_TAGS);
+use vars qw/@EXPORT_OK %EXPORT_TAGS @CHECKOUT_ALL_PHASES/;
+
 
 BEGIN {
-    use base 'Exporter';
+    use base qw/Exporter/;
+    use Handel::L10N qw/translate/;
 };
 
 use constant CART_MODE_APPEND  => 3;
@@ -18,22 +20,21 @@ use constant CART_TYPE_SAVED   => 1;
 use constant ORDER_TYPE_TEMP   => 0;
 use constant ORDER_TYPE_SAVED  => 1;
 
-use constant RETURNAS_AUTO     => 0;
-use constant RETURNAS_ITERATOR => 1;
-use constant RETURNAS_LIST     => 2;
-use constant RETURNAS_ARRAY    => 2;
-
 use constant CHECKOUT_PHASE_INITIALIZE => 1;
 use constant CHECKOUT_PHASE_VALIDATE   => 2;
 use constant CHECKOUT_PHASE_AUTHORIZE  => 4;
-use constant CHECKOUT_PHASE_DELIVER    => 8;
+use constant CHECKOUT_PHASE_FINALIZE   => 8;
+use constant CHECKOUT_PHASE_DELIVER    => 16;
 use constant CHECKOUT_DEFAULT_PHASES   => [CHECKOUT_PHASE_VALIDATE,
                                            CHECKOUT_PHASE_AUTHORIZE,
+                                           CHECKOUT_PHASE_FINALIZE,
                                            CHECKOUT_PHASE_DELIVER];
-use constant CHECKOUT_ALL_PHASES       => [CHECKOUT_PHASE_INITIALIZE,
-                                           CHECKOUT_PHASE_VALIDATE,
-                                           CHECKOUT_PHASE_AUTHORIZE,
-                                           CHECKOUT_PHASE_DELIVER];
+
+@CHECKOUT_ALL_PHASES = (CHECKOUT_PHASE_INITIALIZE,
+                        CHECKOUT_PHASE_VALIDATE,
+                        CHECKOUT_PHASE_AUTHORIZE,
+                        CHECKOUT_PHASE_FINALIZE,
+                        CHECKOUT_PHASE_DELIVER);
 
 use constant CHECKOUT_STATUS_OK        => 1;
 use constant CHECKOUT_STATUS_ERROR     => 2;
@@ -49,13 +50,10 @@ use constant CHECKOUT_HANDLER_ERROR    => 4;
                 CART_TYPE_TEMP
                 ORDER_TYPE_TEMP
                 ORDER_TYPE_SAVED
-                RETURNAS_AUTO
-                RETURNAS_ITERATOR
-                RETURNAS_LIST
-                RETURNAS_ARRAY
                 CHECKOUT_PHASE_INITIALIZE
                 CHECKOUT_PHASE_VALIDATE
                 CHECKOUT_PHASE_AUTHORIZE
+                CHECKOUT_PHASE_FINALIZE
                 CHECKOUT_PHASE_DELIVER
                 CHECKOUT_DEFAULT_PHASES
                 CHECKOUT_ALL_PHASES
@@ -78,14 +76,10 @@ use constant CHECKOUT_HANDLER_ERROR    => 4;
         order => [ qw(ORDER_TYPE_TEMP
                       ORDER_TYPE_SAVED
         )],
-        returnas => [ qw(RETURNAS_AUTO
-                         RETURNAS_ITERATOR
-                         RETURNAS_LIST
-                         RETURNAS_ARRAY
-        )],
         checkout => [ qw(CHECKOUT_PHASE_INITIALIZE
                          CHECKOUT_PHASE_VALIDATE
                          CHECKOUT_PHASE_AUTHORIZE
+                         CHECKOUT_PHASE_FINALIZE
                          CHECKOUT_PHASE_DELIVER
                          CHECKOUT_DEFAULT_PHASES
                          CHECKOUT_ALL_PHASES
@@ -97,6 +91,10 @@ use constant CHECKOUT_HANDLER_ERROR    => 4;
         )]
     );
 
+sub CHECKOUT_ALL_PHASES {
+        return \@CHECKOUT_ALL_PHASES;
+};
+
 sub str_to_const {
     my $str = shift;
 
@@ -113,26 +111,32 @@ Handel::Constants - Common constants used in Handel
 =head1 SYNOPSIS
 
     use Handel::Constants qw(:cart);
-
+    
     my $cart = Handel::Cart->new({
         shopper => 'D597DEED-5B9F-11D1-8DD2-00AA004ABD5E'
     });
-
+    
     if ($cart->type == CART_TYPE_SAVED) {
         print 'This cart is saved!';
     };
 
 =head1 DESCRIPTION
 
-C<Handel::Constants> contains a set of constants used throughout C<Handel>. It
-may be useful (or even a good idea) to use these in your code. :-)
+Handel::Constants contains a set of constants used throughout Handel. It may be
+useful (or even a good idea) to use these in your code. :-)
 
-By default, C<Handel::Constants> export C<nothing>. Use can use the export tags
+By default, Handel::Constants export I<nothing>. You can use the export tags
 below to export all or only certain groups of constants.
 
-=head1 METHODS
+=head1 FUNCTIONS
 
-=head2 str_to_const($)
+=head2 str_to_const
+
+=over
+
+=item Arguments: $constant_name
+
+=back
 
 Converts a string version of a constant into that constants value.
 
@@ -144,7 +148,7 @@ Converts a string version of a constant into that constants value.
 
 All items in the saved cart will be appended to the list of items in the current
 cart. No effort will be made to merge items with the same SKU and duplicates
-will be left as seperate items.
+will be left as separate items.
 
 =head2 CART_MODE_MERGE
 
@@ -174,11 +178,18 @@ The phase run when first creating a new order.
 
 =head2 CHECKOUT_PHASE_VALIDATE
 
-The phase run to validate address, shipping, and other information about an order.
+The phase run to validate address, shipping, and other information about an
+order.
 
 =head2 CHECKOUT_PHASE_AUTHORIZE
 
-The phase run when ahtorizing or validating credit card or other payment information.
+The phase run when authorizing or validating credit card or other payment
+information.
+
+=head2 CHECKOUT_PHASE_FINALIZE
+
+The phase to run and post authorization order cleanup, like setting order
+number, before order delivery/confirmation.
 
 =head2 CHECKOUT_PHASE_DELIVER
 
@@ -195,7 +206,8 @@ Contains all available phases.
 
 =head2 CHECKOUT_STATUS_OK
 
-All plugin handlers returned successully and the checkout process has completed.
+All plugin handlers returned successfully and the checkout process has
+completed.
 
 =head2 CHECKOUT_STATUS_ERROR
 
@@ -217,26 +229,6 @@ using L<Handel::Checkout/add_handler>
 Specifies that the plugin handler encountered errors and would like to abort
 the checkout process.
 
-=head2 RETURNAS_AUTO
-
-When calling C<load> or C<items> on C<Handel::Cart>, it will attempt to return
-the most appropriate object. In list context, it will return a list. In
-scalar context, it will return a C<Handel::Iterator> object. If the iterator
-only contains one item, that item will be returns instead.
-
-=head2 RETURNAS_ITERATOR
-
-Always return a C<Handel::Iterator> object regardless of context or the amount
-of retults.
-
-=head2 RETURNAS_LIST
-
-Always return a list regardless of context or the amount of results.
-
-=head2 RETURNAS_ARRAY
-
-Same as C<RETURNAS_LIST>
-
 =head1 EXPORT_TAGS
 
 The following C<%EXPORT_TAGS> are defined for C<Handel::Constants>. See
@@ -250,10 +242,6 @@ This exports all constants found in this module.
 
 This exports all C<CART_*> constants in this module.
 
-=head2 :returnas
-
-This exports all C<RETURNAS_*> constants in this module.
-
 =head1 AUTHOR
 
     Christopher H. Laco
